==> haskell-dependent-sum-0.7.2.0-211.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-sum
version:              0.7.2.0
visibility:           public
id:                   dependent-sum-0.7.2.0-HfTA5YxTWEXGwqGB9upS0D
key:                  dependent-sum-0.7.2.0-HfTA5YxTWEXGwqGB9upS0D
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:             Dependent sum type
description:
    A dependent sum is a generalization of a
    particular way of thinking about the @Either@
    type.  @Either a b@ can be thought of as a
    2-tuple @(tag, value)@, where the value of the
    tag determines the type of the value.  In
    particular, either @tag = Left@ and @value :: a@
    or @tag = Right@ and @value :: b@.

    This package allows you to define your own
    dependent sum types by using your own \"tag\"
    types.

category:             Data, Dependent Types
abi:                  6ab056bc44cd8e89b819bb589336a136
exposed:              True
exposed-modules:
    Data.Dependent.Sum,
    Data.GADT.Compare from some-1.0.6-1FUKmKhhCiB9O9TtG7osbe:Data.GADT.Compare,
    Data.GADT.Show from some-1.0.6-1FUKmKhhCiB9O9TtG7osbe:Data.GADT.Show,
    Data.Some from some-1.0.6-1FUKmKhhCiB9O9TtG7osbe:Data.Some

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dependent-sum-0.7.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dependent-sum-0.7.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dependent-sum-0.7.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum
hs-libraries:         HSdependent-sum-0.7.2.0-HfTA5YxTWEXGwqGB9upS0D
depends:
    base-4.18.2.1 constraints-extras-0.4.0.2-ExpCytIK6glDi6nv6N5Ivc
    some-1.0.6-1FUKmKhhCiB9O9TtG7osbe

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum/html/dependent-sum.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-sum-0.7.2.0-212-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-sum
version:              0.7.2.0
visibility:           public
id:                   dependent-sum-0.7.2.0-qEijTnHeq8F65XWeXqYVy
key:                  dependent-sum-0.7.2.0-qEijTnHeq8F65XWeXqYVy
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:             Dependent sum type
description:
    A dependent sum is a generalization of a
    particular way of thinking about the @Either@
    type.  @Either a b@ can be thought of as a
    2-tuple @(tag, value)@, where the value of the
    tag determines the type of the value.  In
    particular, either @tag = Left@ and @value :: a@
    or @tag = Right@ and @value :: b@.

    This package allows you to define your own
    dependent sum types by using your own \"tag\"
    types.

category:             Data, Dependent Types
abi:                  c255f441a449a2a4b8e1e35136d1e3cb
exposed:              True
exposed-modules:
    Data.Dependent.Sum,
    Data.GADT.Compare from some-1.0.6-1FUKmKhhCiB9O9TtG7osbe:Data.GADT.Compare,
    Data.GADT.Show from some-1.0.6-1FUKmKhhCiB9O9TtG7osbe:Data.GADT.Show,
    Data.Some from some-1.0.6-1FUKmKhhCiB9O9TtG7osbe:Data.Some

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dependent-sum-0.7.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dependent-sum-0.7.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dependent-sum-0.7.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum
hs-libraries:         HSdependent-sum-0.7.2.0-qEijTnHeq8F65XWeXqYVy
depends:
    base-4.18.2.1 constraints-extras-0.4.0.2-KO66OA2DCdd7nSrKrNy5RA
    some-1.0.6-1FUKmKhhCiB9O9TtG7osbe

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum/html/dependent-sum.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
